<?php
/**
 * Car-repair-services Services functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package car-repair-services
 */
define('CAR_REPAIR_SERVICES_THEME_URI', get_template_directory_uri());
define('CAR_REPAIR_SERVICES_THEME_DIR', get_template_directory());
define('CAR_REPAIR_SERVICES_CSS_URL', get_template_directory_uri() . '/css');
define('CAR_REPAIR_SERVICES_JS_URL', get_template_directory_uri() . '/js');
define('CAR_REPAIR_SERVICES_FONTS_URL', get_template_directory_uri() . '/fonts/font-awesome/css');
define('CAR_REPAIR_SERVICES_IMG_URL', CAR_REPAIR_SERVICES_THEME_URI . '/images/');
define('CAR_REPAIR_SERVICES_FREAMWORK_DIRECTORY', CAR_REPAIR_SERVICES_THEME_DIR . '/framework/');
define('CAR_REPAIR_SERVICES_INC_DIRECTORY', CAR_REPAIR_SERVICES_THEME_DIR . '/inc/');
define('CAR_REPAIR_SERVICES_VC_MAP', CAR_REPAIR_SERVICES_THEME_DIR . '/vc_element/');

/*
default config variable
*/
$fonts_areas = array(
	'car_repair_services-body_typography',
	'car_repair_services-heading-1-typography',
	'car_repair_services-heading-2-typography',
	'car_repair_services-heading-3-typography',
	'car_repair_services-heading-4-typography',
	'car_repair_services-heading-5-typography',
	'car_repair_services-heading-6-typography',
	'car_repair_services-widget_title_typography',

);

/*
 * plugin.php has to load to know which plugin is active
 */
require_once( ABSPATH . 'wp-admin/includes/plugin.php' );

/*
 * Enable support TGM features.
 */
require_once(CAR_REPAIR_SERVICES_FREAMWORK_DIRECTORY . "class-tgm-plugin-activation.php");


/*
 * Load Theme Customizer.
 */
require_once(CAR_REPAIR_SERVICES_FREAMWORK_DIRECTORY . "framework_customizer.php");

/*
 * Redux framework configuration
 */

require_once(CAR_REPAIR_SERVICES_FREAMWORK_DIRECTORY . "redux.fallback.php");
require_once(CAR_REPAIR_SERVICES_FREAMWORK_DIRECTORY . "redux.config.php");

/*
 * Enable support TGM configuration.
 */
require_once(CAR_REPAIR_SERVICES_FREAMWORK_DIRECTORY . "config.tgm.php");

/*
 * Load Menu Walker
 */

require_once(CAR_REPAIR_SERVICES_FREAMWORK_DIRECTORY . "nav_menu_walker.php");


/**
 * Implement the post meta.
 */
require get_template_directory() . '/inc/post_meta.php';


/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';


/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';


if ( ! function_exists( 'car_repair_services_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function car_repair_services_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Pool Services, use a find and replace
	 * to change 'car-repair-services' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'car-repair-services', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support('automatic-feed-links');

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'car-repair-services' ),
		'footer-menu' => esc_html__( 'Footer Menu', 'car-repair-services' ),
	) );
	/*
	 * Enable support for custom-background.
	 */
	$defaults = array(
            'default-image' => '',
            'width' => 0,
            'height' => 0,
            'flex-height' => false,
            'flex-width' => false,
            'uploads' => true,
            'random-default' => false,
            'header-text' => true,
            'default-text-color' => '',
            'wp-head-callback' => '',
            'admin-head-callback' => '',
            'admin-preview-callback' => '',
        );

    add_theme_support('custom-header', $defaults);


	$defaults = array(
		'default-color'          => '',
		'default-image'          => '',
		'default-repeat'         => '',
		'default-position-x'     => '',
		'default-attachment'     => '',
		'wp-head-callback'       => '_custom_background_cb',
		'admin-head-callback'    => '',
		'admin-preview-callback' => ''
	);
	add_theme_support( 'custom-background', $defaults );

	/*
	 * Enable support for Post Formats.
	 */
	add_theme_support( 'post-formats', array(
		'aside',
        'image',
		'gallery',
		'audio',
		'video',
		'link',
		'quote',
	) );
	
	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	//Add custom thumb size
	set_post_thumbnail_size(870, 491, false);
    add_image_size('car-repair-services-thumbnail-carousel', 390, 390, true);
	add_image_size('car-repair-services-thumbnail', 357, 242, true);
	add_image_size('car-repair-services-coupon', 570, 310, true);
	add_image_size('car-repair-services-gallery-thumbnail', 370, 370, true);
	add_image_size('car-repair-services-testimonial', 653, 235, true);
}
endif;
add_action( 'after_setup_theme', 'car_repair_services_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function car_repair_services_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'car_repair_services_content_width', 640 );
}
add_action( 'after_setup_theme', 'car_repair_services_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function car_repair_services_widgets_init() {
    
    register_sidebar(array(
        'name' => esc_html__('Blog Sidebar', 'car-repair-services'),
        'id' => 'left_sideber',
		'description'   => esc_html__( 'Blog sidebar area', 'car-repair-services' ),
        'before_widget' => '<div class="%2$s side-block widget" id="%1$s">',
        'after_widget' => "</div>",
        'before_title' => '<h4 class="title-aside">',
        'after_title' => '</h4>',
    ));
	// add by tanvir
	
	register_sidebar(array(
        'name' => esc_html__('Woo Shop Sidebar', 'car-repair-services'),
        'id' => 'woo_shop_sideber',
		'description'   => esc_html__( 'Shop sidebar area', 'car-repair-services' ),
        'before_widget' => '<div class="%2$s side-block widget" id="%1$s">',
        'after_widget' => "</div>",
        'before_title' => '<h4 class="title-aside">',
        'after_title' => '</h4>',
    ));
	// end add by tanvir
	
	
}

// add by tanvir

add_filter('loop_shop_columns', 'loop_columns');
if (!function_exists('loop_columns')) {
	function loop_columns() {
		 if ( is_product() ) {
			 return 4; 
		 }else{
			 return 3; 
		 }
		
	}
}
if (!function_exists('woocommerce_get_sidebar')) {
	function woocommerce_get_sidebar(){
		 if ( is_product() ) {
		 }else{
			 dynamic_sidebar('woo_shop_sideber');
		 }
		
	}
}
if ( ! function_exists( 'woocommerce_pagination' ) ) {

	function woocommerce_pagination($a=false) {
		if(!$a){
			wc_get_template( 'loop/pagination.php' );
		}else{
			wc_get_template( 'loop/pagination-top.php' );
		}
	}
}

// end add by tanvir
add_action( 'widgets_init', 'car_repair_services_widgets_init' );

if (!function_exists('car_repair_service_get_options')) {
	function car_repair_service_get_options(){
		global $car_repair_services_opt;
		return $car_repair_services_opt;
	}
	
}

function car_repair_services_options(){
	global $car_repair_services_opt;
	return $car_repair_services_opt;
}

/**
 * return redux options
 */
if (!function_exists('car_repair_get_options')){
	function car_repair_get_options(){
		global $car_repair_services_opt;
		return $car_repair_services_opt;
	}
	
}

/**
 * Enqueue scripts and styles.
 */

function car_repair_services_front_init_js_var()
{
    global $yith_wcwl, $post, $product;

    wp_localize_script('car-repair-services-custom', 'THEMEURL', CAR_REPAIR_SERVICES_THEME_URI);
    wp_localize_script('car-repair-services-custom', 'IMAGEURL', CAR_REPAIR_SERVICES_THEME_URI.'/images');
    wp_localize_script('car-repair-services-custom', 'CSSURL', CAR_REPAIR_SERVICES_THEME_URI.'/css');
}
add_action('wp_enqueue_scripts', 'car_repair_services_front_init_js_var', 1001);


/**
 * Enqueue scripts and styles.
 */
add_action('wp_enqueue_scripts', 'car_repair_services_scripts', 10000);

function car_repair_services_scripts(){

    $car_repair_services_opt = car_repair_services_options();
	global $fonts_areas; 
	  // Load styles
    if ( !is_plugin_active( 'redux-framework/redux-framework.php' )){
        $protocol = is_ssl() ? 'https' : 'http';
        $subsets = 'latin,cyrillic-ext,latin-ext,cyrillic,greek-ext,greek,vietnamese';
		$variants = ':100,100i,200,200i,300,300i,400,400i,600,600i,700,700i,800,800i,900,900i';
        $query_args = array(
            'family' => 'Muli'.$variants,
            'subset' => $subsets,
        );
        wp_enqueue_style('Muli', esc_url(add_query_arg($query_args,
         "$protocol://fonts.googleapis.com/css")), array(), null);
    }

 
	$font_families = array();
	foreach($fonts_areas as $option){
		
		
		if(isset($car_repair_services_opt[$option]['font-family']) 
		&& $car_repair_services_opt[$option]['font-family'] 
		){
			$font_families[] = $car_repair_services_opt[$option]['font-family'];
			if(isset( $car_repair_services_opt[$option]['subsets'])  && $car_repair_services_opt[$option]['subsets'] !='' )
			$font_subsets[] = $car_repair_services_opt[$option]['subsets'];
			if(isset( $car_repair_services_opt[$option]['font-weight'])  && $car_repair_services_opt[$option]['font-weight'] !=''){
			$font_variants[] = $car_repair_services_opt[$option]['font-weight'];
			}
		}
	}
	$font_families = array_unique($font_families);
	if ( !empty( $font_families )){
        $protocol = is_ssl() ? 'https' : 'http';
        
		if(!empty($font_variants)){
			$variants = ':'.implode(",", $font_variants);
		}else{
			$variants='';
		}
		if(!empty($font_subsets)){
			$subsets =  implode(",", $font_subsets);
		}else{
			$subsets='';
		}
		
		if(!empty($font_families)){
			$font_families = implode('|', $font_families);
		}
		if($subsets!=''){
			$query_args = array(
            'family' => $font_families.$variants,
            'subset' => $subsets,
        );
		}else{
			$query_args = array(
            'family' => $font_families.$variants,
        );
		}
        
        wp_enqueue_style('car-repair-services-google-fonts', esc_url(add_query_arg($query_args,
         "$protocol://fonts.googleapis.com/css")), array(), null);
    }

	/* ===============================================================
	 * CSS Files 
	 * --------------------------------------------------------------- */
	
	/* BOOTSTRAP  ------------------------- */

	wp_enqueue_style( 'bootstrap', 			CAR_REPAIR_SERVICES_CSS_URL . '/plugins/bootstrap.min.css', '', null );
	wp_enqueue_style( 'bootstrap-submenu', 			CAR_REPAIR_SERVICES_CSS_URL . '/plugins/bootstrap-submenu.css', '', null );
	wp_enqueue_style( 'animate', 			CAR_REPAIR_SERVICES_CSS_URL . '/plugins/animate.min.css', '', null );
	wp_enqueue_style( 'slick', 			CAR_REPAIR_SERVICES_CSS_URL . '/plugins/slick.css', '', null );
	wp_enqueue_style( 'car-repair-services-style', get_stylesheet_uri() );
	wp_enqueue_style( 'car-repair-services-wp-default-norm', 			CAR_REPAIR_SERVICES_CSS_URL . '/wp-default-norm.css', '', null );
	wp_enqueue_style( 'bootstrap-datetimepicker', 			CAR_REPAIR_SERVICES_CSS_URL . '/plugins/bootstrap-datetimepicker.min.css', '', null );
	wp_enqueue_style( 'iconfont-style', 			CAR_REPAIR_SERVICES_THEME_URI . '/iconfont/style.css', '', null );
	wp_enqueue_style( 'magnific-popup', 			CAR_REPAIR_SERVICES_THEME_URI . '/css/plugins/magnific-popup.css', '', null );
	
	wp_enqueue_style( 'shopcss', 			CAR_REPAIR_SERVICES_THEME_URI . '/css/shop.css', '', null );



    require_once(CAR_REPAIR_SERVICES_THEME_DIR.'/css/custom_style.php');
	
	$car_repair_services_custom_inline_style = '';

	if (function_exists( 'car_repair_services_get_custom_styles' )) {
		$car_repair_services_custom_inline_style = car_repair_services_get_custom_styles();
	}
 
	wp_add_inline_style( 'car-repair-services-style', $car_repair_services_custom_inline_style );
	
	/* ===============================================================
	 * JS Files 
	 * --------------------------------------------------------------- */

	wp_enqueue_script( 'bootstrap', CAR_REPAIR_SERVICES_JS_URL . '/plugins/bootstrap.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'slick', CAR_REPAIR_SERVICES_JS_URL . '/plugins/slick.min.js', array('jquery'), '', true );

	wp_enqueue_script( 'jquery-form', CAR_REPAIR_SERVICES_JS_URL . '/plugins/jquery.form.js', array('jquery'), '', true );
	$car_repair_services_opt = car_repair_services_options();
	wp_localize_script( 'jquery-form', 'form_option', array('date_format' => $car_repair_services_opt['modal_date_format']) );


	wp_enqueue_script( 'jquery-validate', CAR_REPAIR_SERVICES_JS_URL . '/plugins/jquery.validate.min.js', array('jquery'), '', true ); 
	wp_enqueue_script( 'moment', CAR_REPAIR_SERVICES_JS_URL . '/plugins/moment.js', array('jquery'), '', true ); 
	wp_enqueue_script( 'bootstrap-datetimepicker', CAR_REPAIR_SERVICES_JS_URL . '/plugins/bootstrap-datetimepicker.min.js', array('jquery'), '', true ); 
	wp_enqueue_script( 'jquery-countTo', CAR_REPAIR_SERVICES_JS_URL . '/plugins/jquery.countTo.js', array('jquery'), '', true );
	wp_enqueue_script( 'magnific-popup', CAR_REPAIR_SERVICES_JS_URL . '/plugins/jquery.magnific-popup.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'imagesloaded-pkg', CAR_REPAIR_SERVICES_JS_URL . '/plugins/imagesloaded.pkgd.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'isotope-pkgd', CAR_REPAIR_SERVICES_JS_URL . '/plugins/isotope.pkgd.min.js', array('jquery'), '', true );


	 wp_enqueue_script( 'jquery-ui-spinner', false, array('jquery'));
	/* ====================== Custom JavaScripts -- */
	wp_enqueue_script( 'waypoints', CAR_REPAIR_SERVICES_JS_URL . '/plugins/jquery.waypoints.min.js', array('jquery'), '', true ); 
    wp_enqueue_script( 'forms', CAR_REPAIR_SERVICES_JS_URL . '/forms.js', array('jquery'), '', true ); 

	wp_enqueue_script( 'custom', CAR_REPAIR_SERVICES_JS_URL . '/custom.js', array('jquery','jquery-ui-spinner'), '', true ); 
    wp_localize_script( 'custom', 'ajax_object', array('ajax_url' => admin_url( 'admin-ajax.php' ),'loader_img' => CAR_REPAIR_SERVICES_IMG_URL.'ajax-loader.gif','site_preloader_timeout'=>$car_repair_services_opt['car_repair_services-site-preloader-timeout'] ) );


 
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}


add_action( 'admin_enqueue_scripts', 'car_repair_services_admin_enqueue' );
function car_repair_services_admin_enqueue() {
 wp_enqueue_script( 'car-repair-services-custom-admin', get_template_directory_uri() . '/js/admin.js' );
}

add_action('car_repair_services_breadcrumb', 'car_repair_services_breadcrumb');
function car_repair_services_breadcrumb(){
    global $post, $car_repair_services_opt;
	if(!isset($post->ID)){
	    return false;
	}


	if(!is_front_page() || is_home()){
		if((isset($post->post_type) && is_page()) || is_search() || is_home() || is_single() || is_archive() || is_category()){
			$show_breadcrumb = 'on' ;
			if($show_breadcrumb == 'on' || !$show_breadcrumb){
				?>
				<div class="container">
				<div class="breadcrumbs">
				<!-- Breadcrumb section -->
				<?php
				if ( is_plugin_active( 'wordpress-seo/wp-seo.php' ) && function_exists('yoast_breadcrumb') ) {
					yoast_breadcrumb('','');
				}
				?>
				</div>
				</div>
				<!--end Breadcrumb section -->
				<?php
			}
		}
	}
}
if ( ! function_exists( 'car_repair_comment_nav' ) ) :

function car_repair_comment_nav() {
	// Are there comments to navigate through?
	if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
	?>
	<nav class="navigation comment-navigation">
		<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'car-repair-services' ); ?></h2>
		<div class="nav-links">
			<?php
				if ( $prev_link = get_previous_comments_link( esc_html__( 'Older Comments', 'car-repair-services' ) ) ) :
					printf( '<div class="nav-previous">%s</div>', $prev_link );
				endif;

				if ( $next_link = get_next_comments_link( esc_html__( 'Newer Comments', 'car-repair-services' ) ) ) :
					printf( '<div class="nav-next">%s</div>', $next_link );
				endif;
			?>
		</div><!-- .nav-links -->
	</nav><!-- .comment-navigation -->
	<?php
	endif;
}
endif;

add_action('car_repair_services_header_loader', 'car_repair_services_header_loader_function');

if (!function_exists('car_repair_services_header_loader_function')) {

	function car_repair_services_header_loader_function()
	{
	$car_repair_services = car_repair_services_options();

	  if(isset($car_repair_services['car_repair_services-site-preloader']) && $car_repair_services['car_repair_services-site-preloader']){

	  	if(isset($car_repair_services['car_repair_services-site-preloader-image']) && $car_repair_services['car_repair_services-site-preloader-image']['url']!=''){
	  		?>
	  		<div id="loader-wrapper">
				<div class="loader custom-loader">
					<img src="<?php echo $car_repair_services['car_repair_services-site-preloader-image']['url'] ; ?>">
				</div>
			</div>

	  		<?php
	  		
	  	}else{
	  		
		?>
			<div id="loader-wrapper">
				<div class="loader">
					<div class="line"></div>
					<div class="line"></div>
					<div class="line"></div>
					<div class="line"></div>
					<div class="line"></div>
					<div class="line"></div>
					<div class="subline"></div>
					<div class="subline"></div>
					<div class="subline"></div>
					<div class="subline"></div>
					<div class="subline"></div>
					<div class="loader-circle-1">
						<div class="loader-circle-2"></div>
					</div>
					<div class="needle"></div>
					<div class="loading"><?php esc_html_e('Loading', 'car-repair-services')?></div>
				</div>
			</div>
	<?php
		} 
	  }
	}
}

/* * ****************************************************************
 * Ajax Posts loading
 * ***************************************************************** */

function car_repair_services_testimonial_more_post_ajax() {
    // WP_Query arguments
    $args = array(
        'posts_per_page' => $_POST['post_per_page'],
        'post_type' => 'car-testimonial',
        'orderby' => 'DESC',
        'paged' => $_POST['paged'],
        'no_found_rows' => true,
    );

    $style = $_POST['grid_style'];

    // The Query
    $query = new WP_Query($args);
    // The Loop
    if ($query->have_posts()) {
        while ($query->have_posts()) {
            $query->the_post();
            global $post;
            $post->style = $style;
            get_template_part('template-parts/testimonial', get_post_format());
        }
    } else {
        // no posts found
    }
    // Restore original Post Data
    wp_reset_postdata();
    die();
}


add_action('wp_ajax_testimonial_more_post_ajax', 'car_repair_services_testimonial_more_post_ajax');
add_action('wp_ajax_nopriv_testimonial_more_post_ajax', 'car_repair_services_testimonial_more_post_ajax');

function car_repair_services_coupon_popup_ajax() {

    $post_id = $_POST['post_id'];
    $coupon_top_left = get_post_meta($post_id, 'framework-coupon-top-left', true);
    $coupon_top_right = get_post_meta($post_id, 'framework-coupon-top-right', true);
    $coupon_bottom_left = get_post_meta($post_id, 'framework-coupon-bottom-left', true);
    $coupon_bottom_right = get_post_meta($post_id, 'framework-coupon-bottom-right', true);
    ?>
    <div class="modal fade" id="myModal" tabindex="-1" role="dialog" aria-labelledby="myModalLabel">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                    <h4 class="modal-title" id="myModalLabel"><?php echo esc_html__('Coupon', 'car-repair-services');?></h4>
                </div>
                <div class="modal-body" id="modal-coupon">
                    <div>
                        <div class="coupon-print">
                            <div class="coupon-print-inside">
                                <div class="coupon-print-row-top">
                                    <div class="coupon-print-col-left">
                                        <i><?php echo esc_html($coupon_top_left) ; ?> </i>
                                    </div>
                                    <div class="coupon-print-col-right">
                                        <div class="contact-info"><i class="icon icon-locate"></i>
                                         <?php echo esc_html($coupon_top_right) ; ?>
                                        </div>
                                    </div>
                                </div>
                                <?php echo get_the_post_thumbnail($post_id, 'car-repair-services-coupon', array('class' => 'img-responsive-inline')); ?>
                                <div class="coupon-print-row-bot">
                                    <div class="coupon-print-col-left">
                                        <?php echo esc_html($coupon_bottom_left) ; ?>
                                    </div>
                                    <div class="coupon-print-col-right text-right">
                                        <?php echo esc_html($coupon_bottom_right) ; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div> 
                </div>
                <div class="modal-footer">
                    <button type="button" id="btn_save_close" class="btn btn-default" data-dismiss="modal"><?php echo esc_html__('Close', 'car-repair-services') ?></button>
                    <button id="btn_save_and_close" type="button" class="btn btn-primary"><?php echo esc_html__('Print', 'car-repair-services') ?> </button>
                </div>
            </div>
        </div>
    </div>
    <?php
    exit();
}

add_action('wp_ajax_coupon_popup_ajax', 'car_repair_services_coupon_popup_ajax');
add_action('wp_ajax_nopriv_coupon_popup_ajax', 'car_repair_services_coupon_popup_ajax');



function woocommerce_template_loop_product_title() {
		echo '<h3 class="woocommerce-loop-product__title">' . get_the_title() . '</h3>';
	}

remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
add_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_upsells', 15 );

if ( ! function_exists( 'woocommerce_output_upsells' ) ) {
	function woocommerce_output_upsells() {
	    woocommerce_upsell_display( 4,4 ); // Display 4 products in rows of 4
	}
}

remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display');
add_action( 'woocommerce_cart_collaterals', 'woocommerce_output_cross_sell_display', 15 );

if ( ! function_exists( 'woocommerce_output_cross_sell_display' ) ) {
	function woocommerce_output_cross_sell_display() {
	    woocommerce_cross_sell_display( 2,2 ); // Display 4 products in rows of 4
	}
}


add_action( 'after_setup_theme', 'car_repair_services_view_product_design' );
 
function car_repair_services_view_product_design() {
	add_theme_support( 'woocommerce' );
    add_theme_support( 'wc-product-gallery-zoom' );
    add_theme_support( 'wc-product-gallery-lightbox' );
    add_theme_support( 'wc-product-gallery-slider' );
}


function woocommerce_template_loop_add_to_cart( $args = array() ) {
		global $product;

		if ( $product ) {
			$defaults = array(
				'quantity' => 1,
				'class'    => implode( ' ', array_filter( array(
						'product_type_' . $product->get_type(),
						$product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
						$product->supports( 'ajax_add_to_cart' ) ? 'ajax_add_to_cart' : '',
				) ) ),
			);

			$args = apply_filters( 'woocommerce_loop_add_to_cart_args', wp_parse_args( $args, $defaults ), $product );

			wc_get_template( 'loop/add-to-cart.php', $args );
		}
	}
	

function car_repair_services_add_to_cart_fragment( $fragments ) {
 
    ob_start();
    $count = WC()->cart->cart_contents_count;
    ?>
    <a class="cart-contents icon icon-shop-cart" href="javascript:void(0)<?php //echo WC()->cart->get_cart_url(); ?>" title="<?php _e( 'View your shopping cart' ,'car-repair-services'); ?>"><?php
    if ( $count > 0 ) {
        ?>
        <span class="badge cart-contents-count"><?php echo esc_html( $count ); ?></span>
        <?php            
    }
        ?></a>
			
 <?php
    $fragments['a.cart-contents'] = ob_get_clean();
     
    return $fragments;
}
add_filter( 'woocommerce_add_to_cart_fragments', 'car_repair_services_add_to_cart_fragment' );
add_filter( 'woocommerce_add_to_cart_fragments', 'car_repair_services_add_to_cart_fragment_details' );

function car_repair_services_add_to_cart_fragment_details ($fragments) {

    ob_start();
    ?>

    <div class="header-cart-dropdown">
        <?php get_template_part('woocommerce/cart/mini','cart');?>
    </div>

    <?php $fragments['div.header-cart-dropdown'] = ob_get_clean();

    return $fragments;

} 





function woocommerce_widget_shopping_cart_button_view_cart() {
		echo '<a href="' . esc_url( wc_get_cart_url() ) . '" class="btn wc-forward">' . esc_html__( 'View cart', 'car-repair-services' ) . '</a>';
}

function woocommerce_widget_shopping_cart_proceed_to_checkout() {
	echo '<a href="' . esc_url( wc_get_checkout_url() ) . '" class="btn btn-invert checkout wc-forward">' . esc_html__( 'Checkout', 'car-repair-services' ) . '</a>';
}


function car_repair_services_remove_item_from_cart() {
	$cart = WC()->instance()->cart;
	$id = $_POST['product_id'];
	$cart_id = $cart->generate_cart_id($id);
	$cart_item_id = $cart->find_product_in_cart($cart_id);
	$array=array();
	if($cart_item_id){
	   $cart->set_quantity($cart_item_id, 0);
	   //$array['success']=true;
	   WC_AJAX::get_refreshed_fragments();
	}else{
		$array['error']=true;
		echo json_encode($array);
		
	}
	
	exit();
}

add_action('wp_ajax_remove_item_from_cart', 'car_repair_services_remove_item_from_cart');
add_action('wp_ajax_nopriv_remove_item_from_cart', 'car_repair_services_remove_item_from_cart');



// Display 24 products per page. Goes in functions.php
add_filter( 'loop_shop_per_page', create_function( '$cols', 'return 9;' ), 20 );
// Display Update car Added success massage.
add_filter( 'wc_add_to_cart_message_html', 'car_repair_services_wc_add_to_cart_message_html_func',10, 2 );
function car_repair_services_wc_add_to_cart_message_html_func ($message, $product_id) {
 $message=preg_replace('#<a.*?>([^>]*)</a>#i', '<a href="' . esc_url( wc_get_cart_url() ) . '" class="btn btn-invert wc-forward">' . esc_html__( 'View cart', 'car-repair-services' ) . '</a>', $message);
    return $message;
} 

// Display Update car Added Error massage.
add_filter( 'woocommerce_add_error', 'car_repair_services_add_error' );
function car_repair_services__add_error( $error ) {
 $error=preg_replace('#<a.*?>([^>]*)</a>#i', '<a href="' . esc_url( wc_get_cart_url() ) . '" class="btn btn-invert wc-forward">' . esc_html__( 'View cart', 'car-repair-services' ) . '</a>', $error);
    return $error;
}

function car_repair_services_more_post_ajax(){
	
	if( isset($_POST['pageNumber']) ){ $pageNumber = $_POST['pageNumber']; }else{ $pageNumber = ''; };
	if( isset($_POST['post_per_load']) ){ $posts_per_page = $_POST['post_per_load']; }else{ $posts_per_page = ''; };
	// WP_Query arguments
	$args = array(
		'post_type'              => array( 'post' ),
		'post_status'            => array( 'publish' ),
		'nopaging'               => false,
		'paged'        			 => $pageNumber,
		'posts_per_page'         => $posts_per_page,
	);

	// The Query
	$query = new WP_Query( $args );
	$post_count=$query->found_posts;
	$nextPost='';

	if(ceil($post_count/$posts_per_page)== $pageNumber || $post_count ==0)
		$nextPost='blank';

	ob_start();
	if ( $query->have_posts() ) {
		while ( $query->have_posts() ) {
			$query->the_post();
			get_template_part( 'template-parts/content',get_post_format() );
		}
	} else {
		// no posts found
	}
	$output =ob_get_clean();
	$resultArray = array("html" => $output,"count" => $nextPost);
    echo json_encode($resultArray);
	// Restore original Post Data
	wp_reset_postdata();
	die();
}
add_action('wp_ajax_car_repair_services_more_post_ajax', 'car_repair_services_more_post_ajax');
add_action('wp_ajax_nopriv_car_repair_services_more_post_ajax', 'car_repair_services_more_post_ajax');

function car_repair_services_add_editor_styles() {
    add_editor_style( CAR_REPAIR_SERVICES_CSS_URL.'/editor-style.css' );
}
add_action( 'admin_init', 'car_repair_services_add_editor_styles' );

	

